
# Shorthands
- parity with Arg keys
- either:
  - via BoundParameter
  - recusive lookup

# Union or tuple[type] for
- Coder.typ 
- Arg key element
- Shorthand key element


# broken
- substitution
- Plan order:
  - position not used?
  - "remove, status, run" is actually "remove, run, status", why?
    - dir() is sorted
    - preserving order would need manual __mro__ interactions


# misc
- peel off args